@@ -321,7 +321,7 @@ identifyLocalFunctions =
 function(nodes)
 {
   defs = character()
-  for(i in seq(along = nodes)) {
+  for(i in seq(along.with = nodes)) {
      tmp = nodes[[i]]
      if(length(tmp@functions) && any(w <- is.na(tmp@functions))) {
         tmp@functions[w] = names(tmp@functions[w]) %in% defs
@@ -347,7 +347,8 @@ setMethod("getInputs", "function",
     ## create dummy node which declares the formal arguments so they
     ## don't show up as globals later. the call itself "outputs" these
     ## "variables"
-    vars = new("ScriptNodeInfo", outputs = names(formals(e)))
+    v = names(formals(e))                
+    vars = new("ScriptNodeInfo", outputs = if(length(v)) v else character())
     exprs = as.list(body(e))
     ## do we really want to keep the "{" around? Currently a test fails
     ## if we remove it (length of output) but the test could be changed...
